
extern void Interface_Plugins_Run(void);
extern void Interface_Plugins_Winch(void);
extern void Interface_Plugins_Output(void);
extern void Interface_Plugins_PluginOutput(void);
extern void Interface_Plugins_HidePluginOutput(void);

/* EOF */
